package java.applet;

import javax.accessibility.AccessibleState;
import javax.accessibility.AccessibleStateSet;
import javax.accessibility.AccessibleRole;
import java.util.Locale;
import sun.applet.AppletAudioClip;
import java.net.MalformedURLException;
import java.awt.Image;
import java.awt.Dimension;
import java.net.URL;
import java.awt.AWTPermission;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.awt.HeadlessException;
import java.awt.GraphicsEnvironment;
import javax.accessibility.AccessibleContext;
import java.awt.Panel;

public class Applet extends Panel
{
    private transient AppletStub stub;
    private static final long serialVersionUID = -5836846270535785031L;
    AccessibleContext accessibleContext;
    
    public Applet() throws HeadlessException {
        this.accessibleContext = null;
        if (GraphicsEnvironment.isHeadless()) {
            throw new HeadlessException();
        }
        return;
    }
    
    private void readObject(ObjectInputStream objectInputStream) throws ClassNotFoundException, IOException, HeadlessException {
        if (GraphicsEnvironment.isHeadless()) {
            throw new HeadlessException();
        }
        objectInputStream.defaultReadObject();
        return;
    }
    
    public final void setStub(AppletStub stub) {
        if (this.stub != null) {
            SecurityManager securityManager = System.getSecurityManager();
            if (securityManager != null) {
                securityManager.checkPermission(new AWTPermission("setAppletStub"));
            }
        }
        this.stub = stub;
    }
    
    public boolean isActive() {
        return this.stub != null && this.stub.isActive();
    }
    
    public URL getDocumentBase() {
        return this.stub.getDocumentBase();
    }
    
    public URL getCodeBase() {
        return this.stub.getCodeBase();
    }
    
    public String getParameter(String s) {
        return this.stub.getParameter(s);
    }
    
    public AppletContext getAppletContext() {
        return this.stub.getAppletContext();
    }
    
    @Override
    public void resize(int width, int height) {
        Dimension size = this.size();
        if (size.width != width || size.height != height) {
            super.resize(width, height);
            if (this.stub != null) {
                this.stub.appletResize(width, height);
            }
        }
    }
    
    @Override
    public void resize(Dimension dimension) {
        this.resize(dimension.width, dimension.height);
    }
    
    @Override
    public boolean isValidateRoot() {
        return true;
    }
    
    public void showStatus(String s) {
        this.getAppletContext().showStatus(s);
    }
    
    public Image getImage(URL url) {
        return this.getAppletContext().getImage(url);
    }
    
    public Image getImage(URL context, String spec) {
        try {
            return this.getImage(new URL(context, spec));
        }
        catch (MalformedURLException ex) {
            return null;
        }
    }
    
    public static final AudioClip newAudioClip(URL url) {
        return new AppletAudioClip(url);
    }
    
    public AudioClip getAudioClip(URL url) {
        return this.getAppletContext().getAudioClip(url);
    }
    
    public AudioClip getAudioClip(URL context, String spec) {
        try {
            return this.getAudioClip(new URL(context, spec));
        }
        catch (MalformedURLException ex) {
            return null;
        }
    }
    
    public String getAppletInfo() {
        return null;
    }
    
    @Override
    public Locale getLocale() {
        Locale locale = super.getLocale();
        if (locale == null) {
            return Locale.getDefault();
        }
        return locale;
    }
    
    public String[][] getParameterInfo() {
        return (String[][])null;
    }
    
    public void play(URL url) {
        AudioClip audioClip = this.getAudioClip(url);
        if (audioClip != null) {
            audioClip.play();
        }
    }
    
    public void play(URL url, String s) {
        AudioClip audioClip = this.getAudioClip(url, s);
        if (audioClip != null) {
            audioClip.play();
        }
    }
    
    public void init() {
    }
    
    public void start() {
    }
    
    public void stop() {
    }
    
    public void destroy() {
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new Applet.AccessibleApplet();
        }
        return this.accessibleContext;
    }
    
    protected class AccessibleApplet extends Panel.AccessibleAWTPanel
    {
        private static final long serialVersionUID = 8127374778187708896L;
        
        @Override
        public AccessibleRole getAccessibleRole() {
            return AccessibleRole.FRAME;
        }
        
        @Override
        public AccessibleStateSet getAccessibleStateSet() {
            AccessibleStateSet accessibleStateSet = super.getAccessibleStateSet();
            accessibleStateSet.add(AccessibleState.ACTIVE);
            return accessibleStateSet;
        }
    }
}
